==> vue-numeric-2.8.0.tgz: package/lib/mobile.js <==
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/numeric/vue";
import { defineComponent, directive, props, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import bind from "@dft-vue-2-opentiny/vue-renderless/common/deps/repeat-click";
import { iconChevronDown, iconChevronUp, iconMinus, iconPlus } from "@dft-vue-2-opentiny/vue-icon";
import "@dft-vue-2-opentiny/vue-theme-mobile/numeric/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  directives: directive({
    repeatClick: {
      bind
    }
  }),
  components: {
    IconChevronDown: iconChevronDown(),
    IconChevronUp: iconChevronUp(),
    IconMinus: iconMinus(),
    IconPlus: iconPlus()
  },
  props: [].concat(props, ["step", "stepStrictly", "max", "min", "modelValue", "disabled", "size", "controls", "controlsPosition", "name", "label", "placeholder", "precision", "circulate", "theme"]),
  emits: ["update:modelValue", "change", "blur", "focus"],
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: ["tiny-mobile-numeric", _vm.state.inputSize ? "tiny-mobile-numeric--" + _vm.state.inputSize : "", {
      "is-disabled": _vm.state.inputDisabled
    }, {
      "is-without-controls": !_vm.controls
    }, {
      "is-controls-right": _vm.state.controlsAtRight
    }, {
      "is-round": _vm.theme === "round"
    }],
    on: {
      "dragstart": function dragstart($event) {
        $event.preventDefault();
      },
      "&mousewheel": function mousewheel($event) {
        return _vm.mouseEvent($event);
      }
    }
  }, [_vm.controls ? _c("span", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.decrease,
      expression: "decrease"
    }],
    staticClass: "tiny-mobile-numeric__decrease",
    class: {
      "is-disabled": _vm.state.minDisabled
    },
    attrs: {
      "role": "button"
    },
    on: {
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter"))
          return null;
        return _vm.decrease($event);
      }
    }
  }, [_c(_vm.state.controlsAtRight ? "icon-chevron-down" : "icon-minus", {
    tag: "component"
  })], 1) : _vm._e(), _vm.controls ? _c("span", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.increase,
      expression: "increase"
    }],
    staticClass: "tiny-mobile-numeric__increase",
    class: {
      "is-disabled": _vm.state.maxDisabled
    },
    attrs: {
      "role": "button"
    },
    on: {
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter"))
          return null;
        return _vm.increase($event);
      }
    }
  }, [_c(_vm.state.controlsAtRight ? "icon-chevron-up" : "icon-plus", {
    tag: "component"
  })], 1) : _vm._e(), _c("div", {
    class: ["tiny-mobile-numeric__input", _vm.state.inputSize ? "tiny-input-" + _vm.state.inputSize : "", _vm.state.inputDisabled ? "is-disabled" : ""]
  }, [_c("input", {
    ref: "input",
    staticClass: "tiny-mobile-numeric__input-inner",
    attrs: {
      "placeholder": _vm.placeholder,
      "max": _vm.max,
      "min": _vm.min,
      "name": _vm.name,
      "aria-label": _vm.label
    },
    domProps: {
      "value": _vm.state.displayValue
    },
    on: {
      "keydown": [function($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "up", 38, $event.key, ["Up", "ArrowUp"]))
          return null;
        $event.preventDefault();
        return _vm.increase($event);
      }, function($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "down", 40, $event.key, ["Down", "ArrowDown"]))
          return null;
        $event.preventDefault();
        return _vm.decrease($event);
      }],
      "blur": _vm.handleBlur,
      "focus": _vm.handleFocus,
      "input": _vm.handleInput,
      "change": _vm.handleInputChange
    }
  })])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobile as default
};

==> vue-numeric-2.21.0.tgz: package/lib/mobile.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/numeric/vue';
import { defineComponent, directive, props, setup } from '@opentinyvue/vue-common';
import bind from '@opentinyvue/vue-renderless/common/deps/repeat-click';
import { iconChevronDown, iconChevronUp, iconMinus, iconPlus } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme-mobile/numeric/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  directives: directive({
    repeatClick: {
      bind
    }
  }),
  components: {
    IconChevronDown: iconChevronDown(),
    IconChevronUp: iconChevronUp(),
    IconMinus: iconMinus(),
    IconPlus: iconPlus()
  },
  props: [].concat(props, ["step", "stepStrictly", "max", "min", "modelValue", "disabled", "size", "controls", "controlsPosition", "name", "label", "placeholder", "precision", "circulate", "theme", "changeCompat"]),
  emits: ["update:modelValue", "change", "blur", "focus"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: ["tiny-mobile-numeric", _vm.state.inputSize ? "tiny-mobile-numeric--" + _vm.state.inputSize : "", {
      "is-disabled": _vm.state.inputDisabled
    }, {
      "is-without-controls": !_vm.controls
    }, {
      "is-controls-right": _vm.state.controlsAtRight
    }, {
      "is-round": _vm.theme === "round"
    }],
    on: {
      "dragstart": function dragstart($event) {
        $event.preventDefault();
      },
      "&mousewheel": function mousewheel($event) {
        return _vm.mouseEvent.apply(null, arguments);
      }
    }
  }, [_vm.controls ? _c("span", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.decrease,
      expression: "decrease"
    }],
    staticClass: "tiny-mobile-numeric__decrease",
    class: {
      "is-disabled": _vm.state.minDisabled
    },
    attrs: {
      "role": "button"
    },
    on: {
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) return null;
        return _vm.decrease.apply(null, arguments);
      }
    }
  }, [_c(_vm.state.controlsAtRight ? "icon-chevron-down" : "icon-minus", {
    tag: "component"
  })], 1) : _vm._e(), _vm.controls ? _c("span", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.increase,
      expression: "increase"
    }],
    staticClass: "tiny-mobile-numeric__increase",
    class: {
      "is-disabled": _vm.state.maxDisabled
    },
    attrs: {
      "role": "button"
    },
    on: {
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) return null;
        return _vm.increase.apply(null, arguments);
      }
    }
  }, [_c(_vm.state.controlsAtRight ? "icon-chevron-up" : "icon-plus", {
    tag: "component"
  })], 1) : _vm._e(), _c("div", {
    class: ["tiny-mobile-numeric__input", _vm.state.inputSize ? "tiny-input-" + _vm.state.inputSize : "", _vm.state.inputDisabled ? "is-disabled" : ""]
  }, [_c("input", {
    ref: "input",
    staticClass: "tiny-mobile-numeric__input-inner",
    attrs: {
      "placeholder": _vm.placeholder,
      "max": _vm.max,
      "min": _vm.min,
      "name": _vm.name,
      "aria-label": _vm.label
    },
    domProps: {
      "value": _vm.state.displayValue
    },
    on: {
      "keydown": [function($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "up", 38, $event.key, ["Up", "ArrowUp"])) return null;
        $event.preventDefault();
        return _vm.increase.apply(null, arguments);
      }, function($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "down", 40, $event.key, ["Down", "ArrowDown"])) return null;
        $event.preventDefault();
        return _vm.decrease.apply(null, arguments);
      }],
      "blur": _vm.handleBlur,
      "focus": _vm.handleFocus,
      "input": _vm.handleInput,
      "change": _vm.handleInputChange
    }
  })])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobile as default };
